# coding: utf-8

"""
    BTCPay Greenfield API

    A full API to use your BTCPay Server  # noqa: E501

    OpenAPI spec version: v1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

import re  # noqa: F401

# python 2 and python 3 compatibility library
import six

from pygreenfield.api_client import ApiClient


class MiscelleneousApi(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    Ref: https://github.com/swagger-api/swagger-codegen
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

    def i_invoice_id_get(self, invoice_id, **kwargs):  # noqa: E501
        """Invoice checkout  # noqa: E501

        View the checkout page of an invoice  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.i_invoice_id_get(invoice_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str invoice_id: The invoice id (required)
        :param str lang: The preferred language of the checkout page. You can use \"auto\" to use the language of the customer's browser or see the list of language codes with [this operation](#operation/langCodes).
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.i_invoice_id_get_with_http_info(invoice_id, **kwargs)  # noqa: E501
        else:
            (data) = self.i_invoice_id_get_with_http_info(invoice_id, **kwargs)  # noqa: E501
            return data

    def i_invoice_id_get_with_http_info(self, invoice_id, **kwargs):  # noqa: E501
        """Invoice checkout  # noqa: E501

        View the checkout page of an invoice  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.i_invoice_id_get_with_http_info(invoice_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str invoice_id: The invoice id (required)
        :param str lang: The preferred language of the checkout page. You can use \"auto\" to use the language of the customer's browser or see the list of language codes with [this operation](#operation/langCodes).
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['invoice_id', 'lang']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method i_invoice_id_get" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'invoice_id' is set
        if ('invoice_id' not in params or
                params['invoice_id'] is None):
            raise ValueError("Missing the required parameter `invoice_id` when calling `i_invoice_id_get`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'invoice_id' in params:
            path_params['invoiceId'] = params['invoice_id']  # noqa: E501

        query_params = []
        if 'lang' in params:
            query_params.append(('lang', params['lang']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['text/html'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/i/{invoiceId}', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type=None,  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def lang_codes(self, **kwargs):  # noqa: E501
        """Language codes  # noqa: E501

        The supported language codes  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.lang_codes(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :return: list[InlineResponse2002]
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.lang_codes_with_http_info(**kwargs)  # noqa: E501
        else:
            (data) = self.lang_codes_with_http_info(**kwargs)  # noqa: E501
            return data

    def lang_codes_with_http_info(self, **kwargs):  # noqa: E501
        """Language codes  # noqa: E501

        The supported language codes  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.lang_codes_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :return: list[InlineResponse2002]
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = []  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method lang_codes" % key
                )
            params[key] = val
        del params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/misc/lang', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='list[InlineResponse2002]',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def permissions_metadata(self, **kwargs):  # noqa: E501
        """Permissions metadata  # noqa: E501

        The metadata of available permissions  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.permissions_metadata(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :return: list[InlineResponse2001]
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.permissions_metadata_with_http_info(**kwargs)  # noqa: E501
        else:
            (data) = self.permissions_metadata_with_http_info(**kwargs)  # noqa: E501
            return data

    def permissions_metadata_with_http_info(self, **kwargs):  # noqa: E501
        """Permissions metadata  # noqa: E501

        The metadata of available permissions  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.permissions_metadata_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :return: list[InlineResponse2001]
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = []  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method permissions_metadata" % key
                )
            params[key] = val
        del params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/misc/permissions', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='list[InlineResponse2001]',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)



# coding: utf-8

"""
    BTCPay Greenfield API

    A full API to use your BTCPay Server  # noqa: E501

    OpenAPI spec version: v1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class PullPaymentData(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'id': 'str',
        'name': 'str',
        'description': 'str',
        'currency': 'str',
        'amount': 'str',
        'period': 'int',
        'bolt11_expiration': 'str',
        'auto_approve_claims': 'bool',
        'archived': 'bool',
        'view_link': 'str'
    }

    attribute_map = {
        'id': 'id',
        'name': 'name',
        'description': 'description',
        'currency': 'currency',
        'amount': 'amount',
        'period': 'period',
        'bolt11_expiration': 'BOLT11Expiration',
        'auto_approve_claims': 'autoApproveClaims',
        'archived': 'archived',
        'view_link': 'viewLink'
    }

    def __init__(self, id=None, name=None, description=None, currency=None, amount=None, period=None, bolt11_expiration=None, auto_approve_claims=False, archived=None, view_link=None):  # noqa: E501
        """PullPaymentData - a model defined in Swagger"""  # noqa: E501
        self._id = None
        self._name = None
        self._description = None
        self._currency = None
        self._amount = None
        self._period = None
        self._bolt11_expiration = None
        self._auto_approve_claims = None
        self._archived = None
        self._view_link = None
        self.discriminator = None
        if id is not None:
            self.id = id
        if name is not None:
            self.name = name
        if description is not None:
            self.description = description
        if currency is not None:
            self.currency = currency
        if amount is not None:
            self.amount = amount
        if period is not None:
            self.period = period
        if bolt11_expiration is not None:
            self.bolt11_expiration = bolt11_expiration
        if auto_approve_claims is not None:
            self.auto_approve_claims = auto_approve_claims
        if archived is not None:
            self.archived = archived
        if view_link is not None:
            self.view_link = view_link

    @property
    def id(self):
        """Gets the id of this PullPaymentData.  # noqa: E501

        Id of the pull payment  # noqa: E501

        :return: The id of this PullPaymentData.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this PullPaymentData.

        Id of the pull payment  # noqa: E501

        :param id: The id of this PullPaymentData.  # noqa: E501
        :type: str
        """

        self._id = id

    @property
    def name(self):
        """Gets the name of this PullPaymentData.  # noqa: E501

        Name given to pull payment when it was created  # noqa: E501

        :return: The name of this PullPaymentData.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this PullPaymentData.

        Name given to pull payment when it was created  # noqa: E501

        :param name: The name of this PullPaymentData.  # noqa: E501
        :type: str
        """

        self._name = name

    @property
    def description(self):
        """Gets the description of this PullPaymentData.  # noqa: E501

        Description given to pull payment when it was created  # noqa: E501

        :return: The description of this PullPaymentData.  # noqa: E501
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """Sets the description of this PullPaymentData.

        Description given to pull payment when it was created  # noqa: E501

        :param description: The description of this PullPaymentData.  # noqa: E501
        :type: str
        """

        self._description = description

    @property
    def currency(self):
        """Gets the currency of this PullPaymentData.  # noqa: E501

        The currency of the pull payment's amount  # noqa: E501

        :return: The currency of this PullPaymentData.  # noqa: E501
        :rtype: str
        """
        return self._currency

    @currency.setter
    def currency(self, currency):
        """Sets the currency of this PullPaymentData.

        The currency of the pull payment's amount  # noqa: E501

        :param currency: The currency of this PullPaymentData.  # noqa: E501
        :type: str
        """

        self._currency = currency

    @property
    def amount(self):
        """Gets the amount of this PullPaymentData.  # noqa: E501

        The amount in the currency of this pull payment as a decimal string  # noqa: E501

        :return: The amount of this PullPaymentData.  # noqa: E501
        :rtype: str
        """
        return self._amount

    @amount.setter
    def amount(self, amount):
        """Sets the amount of this PullPaymentData.

        The amount in the currency of this pull payment as a decimal string  # noqa: E501

        :param amount: The amount of this PullPaymentData.  # noqa: E501
        :type: str
        """

        self._amount = amount

    @property
    def period(self):
        """Gets the period of this PullPaymentData.  # noqa: E501

        The length of each period in seconds  # noqa: E501

        :return: The period of this PullPaymentData.  # noqa: E501
        :rtype: int
        """
        return self._period

    @period.setter
    def period(self, period):
        """Sets the period of this PullPaymentData.

        The length of each period in seconds  # noqa: E501

        :param period: The period of this PullPaymentData.  # noqa: E501
        :type: int
        """

        self._period = period

    @property
    def bolt11_expiration(self):
        """Gets the bolt11_expiration of this PullPaymentData.  # noqa: E501

        If lightning is activated, do not accept BOLT11 invoices with expiration less than … days  # noqa: E501

        :return: The bolt11_expiration of this PullPaymentData.  # noqa: E501
        :rtype: str
        """
        return self._bolt11_expiration

    @bolt11_expiration.setter
    def bolt11_expiration(self, bolt11_expiration):
        """Sets the bolt11_expiration of this PullPaymentData.

        If lightning is activated, do not accept BOLT11 invoices with expiration less than … days  # noqa: E501

        :param bolt11_expiration: The bolt11_expiration of this PullPaymentData.  # noqa: E501
        :type: str
        """

        self._bolt11_expiration = bolt11_expiration

    @property
    def auto_approve_claims(self):
        """Gets the auto_approve_claims of this PullPaymentData.  # noqa: E501

        Any payouts created for this pull payment will skip the approval phase upon creation  # noqa: E501

        :return: The auto_approve_claims of this PullPaymentData.  # noqa: E501
        :rtype: bool
        """
        return self._auto_approve_claims

    @auto_approve_claims.setter
    def auto_approve_claims(self, auto_approve_claims):
        """Sets the auto_approve_claims of this PullPaymentData.

        Any payouts created for this pull payment will skip the approval phase upon creation  # noqa: E501

        :param auto_approve_claims: The auto_approve_claims of this PullPaymentData.  # noqa: E501
        :type: bool
        """

        self._auto_approve_claims = auto_approve_claims

    @property
    def archived(self):
        """Gets the archived of this PullPaymentData.  # noqa: E501

        Whether this pull payment is archived  # noqa: E501

        :return: The archived of this PullPaymentData.  # noqa: E501
        :rtype: bool
        """
        return self._archived

    @archived.setter
    def archived(self, archived):
        """Sets the archived of this PullPaymentData.

        Whether this pull payment is archived  # noqa: E501

        :param archived: The archived of this PullPaymentData.  # noqa: E501
        :type: bool
        """

        self._archived = archived

    @property
    def view_link(self):
        """Gets the view_link of this PullPaymentData.  # noqa: E501

        The link to a page to claim payouts to this pull payment  # noqa: E501

        :return: The view_link of this PullPaymentData.  # noqa: E501
        :rtype: str
        """
        return self._view_link

    @view_link.setter
    def view_link(self, view_link):
        """Sets the view_link of this PullPaymentData.

        The link to a page to claim payouts to this pull payment  # noqa: E501

        :param view_link: The view_link of this PullPaymentData.  # noqa: E501
        :type: str
        """

        self._view_link = view_link

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(PullPaymentData, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, PullPaymentData):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    BTCPay Greenfield API

    A full API to use your BTCPay Server  # noqa: E501

    OpenAPI spec version: v1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class ApplicationUserData(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'id': 'str',
        'email': 'str',
        'email_confirmed': 'bool',
        'requires_email_confirmation': 'bool',
        'created': 'AllOfApplicationUserDataCreated',
        'roles': 'list[str]'
    }

    attribute_map = {
        'id': 'id',
        'email': 'email',
        'email_confirmed': 'emailConfirmed',
        'requires_email_confirmation': 'requiresEmailConfirmation',
        'created': 'created',
        'roles': 'roles'
    }

    def __init__(self, id=None, email=None, email_confirmed=None, requires_email_confirmation=None, created=None, roles=None):  # noqa: E501
        """ApplicationUserData - a model defined in Swagger"""  # noqa: E501
        self._id = None
        self._email = None
        self._email_confirmed = None
        self._requires_email_confirmation = None
        self._created = None
        self._roles = None
        self.discriminator = None
        if id is not None:
            self.id = id
        if email is not None:
            self.email = email
        if email_confirmed is not None:
            self.email_confirmed = email_confirmed
        if requires_email_confirmation is not None:
            self.requires_email_confirmation = requires_email_confirmation
        if created is not None:
            self.created = created
        if roles is not None:
            self.roles = roles

    @property
    def id(self):
        """Gets the id of this ApplicationUserData.  # noqa: E501

        The id of the user  # noqa: E501

        :return: The id of this ApplicationUserData.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this ApplicationUserData.

        The id of the user  # noqa: E501

        :param id: The id of this ApplicationUserData.  # noqa: E501
        :type: str
        """

        self._id = id

    @property
    def email(self):
        """Gets the email of this ApplicationUserData.  # noqa: E501

        The email of the user  # noqa: E501

        :return: The email of this ApplicationUserData.  # noqa: E501
        :rtype: str
        """
        return self._email

    @email.setter
    def email(self, email):
        """Sets the email of this ApplicationUserData.

        The email of the user  # noqa: E501

        :param email: The email of this ApplicationUserData.  # noqa: E501
        :type: str
        """

        self._email = email

    @property
    def email_confirmed(self):
        """Gets the email_confirmed of this ApplicationUserData.  # noqa: E501

        True if the email has been confirmed by the user  # noqa: E501

        :return: The email_confirmed of this ApplicationUserData.  # noqa: E501
        :rtype: bool
        """
        return self._email_confirmed

    @email_confirmed.setter
    def email_confirmed(self, email_confirmed):
        """Sets the email_confirmed of this ApplicationUserData.

        True if the email has been confirmed by the user  # noqa: E501

        :param email_confirmed: The email_confirmed of this ApplicationUserData.  # noqa: E501
        :type: bool
        """

        self._email_confirmed = email_confirmed

    @property
    def requires_email_confirmation(self):
        """Gets the requires_email_confirmation of this ApplicationUserData.  # noqa: E501

        True if the email requires email confirmation to log in  # noqa: E501

        :return: The requires_email_confirmation of this ApplicationUserData.  # noqa: E501
        :rtype: bool
        """
        return self._requires_email_confirmation

    @requires_email_confirmation.setter
    def requires_email_confirmation(self, requires_email_confirmation):
        """Sets the requires_email_confirmation of this ApplicationUserData.

        True if the email requires email confirmation to log in  # noqa: E501

        :param requires_email_confirmation: The requires_email_confirmation of this ApplicationUserData.  # noqa: E501
        :type: bool
        """

        self._requires_email_confirmation = requires_email_confirmation

    @property
    def created(self):
        """Gets the created of this ApplicationUserData.  # noqa: E501

        The creation date of the user as a unix timestamp. Null if created before v1.0.5.6  # noqa: E501

        :return: The created of this ApplicationUserData.  # noqa: E501
        :rtype: AllOfApplicationUserDataCreated
        """
        return self._created

    @created.setter
    def created(self, created):
        """Sets the created of this ApplicationUserData.

        The creation date of the user as a unix timestamp. Null if created before v1.0.5.6  # noqa: E501

        :param created: The created of this ApplicationUserData.  # noqa: E501
        :type: AllOfApplicationUserDataCreated
        """

        self._created = created

    @property
    def roles(self):
        """Gets the roles of this ApplicationUserData.  # noqa: E501

        The roles of the user  # noqa: E501

        :return: The roles of this ApplicationUserData.  # noqa: E501
        :rtype: list[str]
        """
        return self._roles

    @roles.setter
    def roles(self, roles):
        """Sets the roles of this ApplicationUserData.

        The roles of the user  # noqa: E501

        :param roles: The roles of this ApplicationUserData.  # noqa: E501
        :type: list[str]
        """

        self._roles = roles

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(ApplicationUserData, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ApplicationUserData):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    BTCPay Greenfield API

    A full API to use your BTCPay Server  # noqa: E501

    OpenAPI spec version: v1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class ApplicationServerInfoNodeStatusData(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'headers': 'int',
        'blocks': 'int',
        'verification_progress': 'float'
    }

    attribute_map = {
        'headers': 'headers',
        'blocks': 'blocks',
        'verification_progress': 'verificationProgress'
    }

    def __init__(self, headers=None, blocks=None, verification_progress=None):  # noqa: E501
        """ApplicationServerInfoNodeStatusData - a model defined in Swagger"""  # noqa: E501
        self._headers = None
        self._blocks = None
        self._verification_progress = None
        self.discriminator = None
        if headers is not None:
            self.headers = headers
        if blocks is not None:
            self.blocks = blocks
        if verification_progress is not None:
            self.verification_progress = verification_progress

    @property
    def headers(self):
        """Gets the headers of this ApplicationServerInfoNodeStatusData.  # noqa: E501

        The height of the chain of header of the internal full node  # noqa: E501

        :return: The headers of this ApplicationServerInfoNodeStatusData.  # noqa: E501
        :rtype: int
        """
        return self._headers

    @headers.setter
    def headers(self, headers):
        """Sets the headers of this ApplicationServerInfoNodeStatusData.

        The height of the chain of header of the internal full node  # noqa: E501

        :param headers: The headers of this ApplicationServerInfoNodeStatusData.  # noqa: E501
        :type: int
        """

        self._headers = headers

    @property
    def blocks(self):
        """Gets the blocks of this ApplicationServerInfoNodeStatusData.  # noqa: E501

        The height of the latest validated block of the internal full node  # noqa: E501

        :return: The blocks of this ApplicationServerInfoNodeStatusData.  # noqa: E501
        :rtype: int
        """
        return self._blocks

    @blocks.setter
    def blocks(self, blocks):
        """Sets the blocks of this ApplicationServerInfoNodeStatusData.

        The height of the latest validated block of the internal full node  # noqa: E501

        :param blocks: The blocks of this ApplicationServerInfoNodeStatusData.  # noqa: E501
        :type: int
        """

        self._blocks = blocks

    @property
    def verification_progress(self):
        """Gets the verification_progress of this ApplicationServerInfoNodeStatusData.  # noqa: E501

        The current synchronization progress  # noqa: E501

        :return: The verification_progress of this ApplicationServerInfoNodeStatusData.  # noqa: E501
        :rtype: float
        """
        return self._verification_progress

    @verification_progress.setter
    def verification_progress(self, verification_progress):
        """Sets the verification_progress of this ApplicationServerInfoNodeStatusData.

        The current synchronization progress  # noqa: E501

        :param verification_progress: The verification_progress of this ApplicationServerInfoNodeStatusData.  # noqa: E501
        :type: float
        """

        self._verification_progress = verification_progress

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(ApplicationServerInfoNodeStatusData, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ApplicationServerInfoNodeStatusData):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    BTCPay Greenfield API

    A full API to use your BTCPay Server  # noqa: E501

    OpenAPI spec version: v1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

import unittest

import pygreenfield
from pygreenfield.api.webhooks_api import WebhooksApi  # noqa: E501
from pygreenfield.rest import ApiException


class TestWebhooksApi(unittest.TestCase):
    """WebhooksApi unit test stubs"""

    def setUp(self):
        self.api = WebhooksApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_api_v1_stores_store_id_webhooks_post(self):
        """Test case for api_v1_stores_store_id_webhooks_post

        Create a new webhook  # noqa: E501
        """
        pass

    def test_api_v1_stores_store_id_webhooks_webhook_id_delete(self):
        """Test case for api_v1_stores_store_id_webhooks_webhook_id_delete

        Delete a webhook  # noqa: E501
        """
        pass

    def test_api_v1_stores_store_id_webhooks_webhook_id_deliveries_delivery_id_get(self):
        """Test case for api_v1_stores_store_id_webhooks_webhook_id_deliveries_delivery_id_get

        Get a webhook delivery  # noqa: E501
        """
        pass

    def test_api_v1_stores_store_id_webhooks_webhook_id_deliveries_delivery_id_redeliver_post(self):
        """Test case for api_v1_stores_store_id_webhooks_webhook_id_deliveries_delivery_id_redeliver_post

        Redeliver the delivery  # noqa: E501
        """
        pass

    def test_api_v1_stores_store_id_webhooks_webhook_id_deliveries_delivery_id_request_get(self):
        """Test case for api_v1_stores_store_id_webhooks_webhook_id_deliveries_delivery_id_request_get

        Get the delivery's request  # noqa: E501
        """
        pass

    def test_api_v1_stores_store_id_webhooks_webhook_id_deliveries_get(self):
        """Test case for api_v1_stores_store_id_webhooks_webhook_id_deliveries_get

        Get latest deliveries  # noqa: E501
        """
        pass

    def test_api_v1_stores_store_id_webhooks_webhook_id_put(self):
        """Test case for api_v1_stores_store_id_webhooks_webhook_id_put

        Update a webhook  # noqa: E501
        """
        pass

    def test_webhokks_get_webhook(self):
        """Test case for webhokks_get_webhook

        Get a webhook of a store  # noqa: E501
        """
        pass

    def test_webhokks_get_webhooks(self):
        """Test case for webhokks_get_webhooks

        Get webhooks of a store  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    BTCPay Greenfield API

    A full API to use your BTCPay Server  # noqa: E501

    OpenAPI spec version: v1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class CreateOnChainTransactionRequest(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'destinations': 'list[CreateOnChainTransactionRequestDestination]',
        'feerate': 'float',
        'proceed_with_payjoin': 'bool',
        'proceed_with_broadcast': 'bool',
        'no_change': 'bool',
        'rbf': 'bool',
        'exclude_unconfirmed': 'bool',
        'selected_inputs': 'list[str]'
    }

    attribute_map = {
        'destinations': 'destinations',
        'feerate': 'feerate',
        'proceed_with_payjoin': 'proceedWithPayjoin',
        'proceed_with_broadcast': 'proceedWithBroadcast',
        'no_change': 'noChange',
        'rbf': 'rbf',
        'exclude_unconfirmed': 'excludeUnconfirmed',
        'selected_inputs': 'selectedInputs'
    }

    def __init__(self, destinations=None, feerate=None, proceed_with_payjoin=True, proceed_with_broadcast=True, no_change=False, rbf=None, exclude_unconfirmed=False, selected_inputs=None):  # noqa: E501
        """CreateOnChainTransactionRequest - a model defined in Swagger"""  # noqa: E501
        self._destinations = None
        self._feerate = None
        self._proceed_with_payjoin = None
        self._proceed_with_broadcast = None
        self._no_change = None
        self._rbf = None
        self._exclude_unconfirmed = None
        self._selected_inputs = None
        self.discriminator = None
        if destinations is not None:
            self.destinations = destinations
        if feerate is not None:
            self.feerate = feerate
        if proceed_with_payjoin is not None:
            self.proceed_with_payjoin = proceed_with_payjoin
        if proceed_with_broadcast is not None:
            self.proceed_with_broadcast = proceed_with_broadcast
        if no_change is not None:
            self.no_change = no_change
        if rbf is not None:
            self.rbf = rbf
        if exclude_unconfirmed is not None:
            self.exclude_unconfirmed = exclude_unconfirmed
        if selected_inputs is not None:
            self.selected_inputs = selected_inputs

    @property
    def destinations(self):
        """Gets the destinations of this CreateOnChainTransactionRequest.  # noqa: E501

        What and where to send money  # noqa: E501

        :return: The destinations of this CreateOnChainTransactionRequest.  # noqa: E501
        :rtype: list[CreateOnChainTransactionRequestDestination]
        """
        return self._destinations

    @destinations.setter
    def destinations(self, destinations):
        """Sets the destinations of this CreateOnChainTransactionRequest.

        What and where to send money  # noqa: E501

        :param destinations: The destinations of this CreateOnChainTransactionRequest.  # noqa: E501
        :type: list[CreateOnChainTransactionRequestDestination]
        """

        self._destinations = destinations

    @property
    def feerate(self):
        """Gets the feerate of this CreateOnChainTransactionRequest.  # noqa: E501

        Transaction fee.  # noqa: E501

        :return: The feerate of this CreateOnChainTransactionRequest.  # noqa: E501
        :rtype: float
        """
        return self._feerate

    @feerate.setter
    def feerate(self, feerate):
        """Sets the feerate of this CreateOnChainTransactionRequest.

        Transaction fee.  # noqa: E501

        :param feerate: The feerate of this CreateOnChainTransactionRequest.  # noqa: E501
        :type: float
        """

        self._feerate = feerate

    @property
    def proceed_with_payjoin(self):
        """Gets the proceed_with_payjoin of this CreateOnChainTransactionRequest.  # noqa: E501

        Whether to attempt to do a BIP78 payjoin if one of the destinations is a BIP21 with payjoin enabled  # noqa: E501

        :return: The proceed_with_payjoin of this CreateOnChainTransactionRequest.  # noqa: E501
        :rtype: bool
        """
        return self._proceed_with_payjoin

    @proceed_with_payjoin.setter
    def proceed_with_payjoin(self, proceed_with_payjoin):
        """Sets the proceed_with_payjoin of this CreateOnChainTransactionRequest.

        Whether to attempt to do a BIP78 payjoin if one of the destinations is a BIP21 with payjoin enabled  # noqa: E501

        :param proceed_with_payjoin: The proceed_with_payjoin of this CreateOnChainTransactionRequest.  # noqa: E501
        :type: bool
        """

        self._proceed_with_payjoin = proceed_with_payjoin

    @property
    def proceed_with_broadcast(self):
        """Gets the proceed_with_broadcast of this CreateOnChainTransactionRequest.  # noqa: E501

        Whether to broadcast the transaction after creating it or to simply return the transaction in hex format.  # noqa: E501

        :return: The proceed_with_broadcast of this CreateOnChainTransactionRequest.  # noqa: E501
        :rtype: bool
        """
        return self._proceed_with_broadcast

    @proceed_with_broadcast.setter
    def proceed_with_broadcast(self, proceed_with_broadcast):
        """Sets the proceed_with_broadcast of this CreateOnChainTransactionRequest.

        Whether to broadcast the transaction after creating it or to simply return the transaction in hex format.  # noqa: E501

        :param proceed_with_broadcast: The proceed_with_broadcast of this CreateOnChainTransactionRequest.  # noqa: E501
        :type: bool
        """

        self._proceed_with_broadcast = proceed_with_broadcast

    @property
    def no_change(self):
        """Gets the no_change of this CreateOnChainTransactionRequest.  # noqa: E501

        Whether to send all the spent coins to the destinations (THIS CAN COST YOU SIGNIFICANT AMOUNTS OF MONEY, LEAVE FALSE UNLESS YOU KNOW WHAT YOU ARE DOING).  # noqa: E501

        :return: The no_change of this CreateOnChainTransactionRequest.  # noqa: E501
        :rtype: bool
        """
        return self._no_change

    @no_change.setter
    def no_change(self, no_change):
        """Sets the no_change of this CreateOnChainTransactionRequest.

        Whether to send all the spent coins to the destinations (THIS CAN COST YOU SIGNIFICANT AMOUNTS OF MONEY, LEAVE FALSE UNLESS YOU KNOW WHAT YOU ARE DOING).  # noqa: E501

        :param no_change: The no_change of this CreateOnChainTransactionRequest.  # noqa: E501
        :type: bool
        """

        self._no_change = no_change

    @property
    def rbf(self):
        """Gets the rbf of this CreateOnChainTransactionRequest.  # noqa: E501

        Whether to enable RBF for the transaction. Leave blank to have it random (beneficial to privacy)  # noqa: E501

        :return: The rbf of this CreateOnChainTransactionRequest.  # noqa: E501
        :rtype: bool
        """
        return self._rbf

    @rbf.setter
    def rbf(self, rbf):
        """Sets the rbf of this CreateOnChainTransactionRequest.

        Whether to enable RBF for the transaction. Leave blank to have it random (beneficial to privacy)  # noqa: E501

        :param rbf: The rbf of this CreateOnChainTransactionRequest.  # noqa: E501
        :type: bool
        """

        self._rbf = rbf

    @property
    def exclude_unconfirmed(self):
        """Gets the exclude_unconfirmed of this CreateOnChainTransactionRequest.  # noqa: E501

        Whether to exclude unconfirmed UTXOs from the transaction.  # noqa: E501

        :return: The exclude_unconfirmed of this CreateOnChainTransactionRequest.  # noqa: E501
        :rtype: bool
        """
        return self._exclude_unconfirmed

    @exclude_unconfirmed.setter
    def exclude_unconfirmed(self, exclude_unconfirmed):
        """Sets the exclude_unconfirmed of this CreateOnChainTransactionRequest.

        Whether to exclude unconfirmed UTXOs from the transaction.  # noqa: E501

        :param exclude_unconfirmed: The exclude_unconfirmed of this CreateOnChainTransactionRequest.  # noqa: E501
        :type: bool
        """

        self._exclude_unconfirmed = exclude_unconfirmed

    @property
    def selected_inputs(self):
        """Gets the selected_inputs of this CreateOnChainTransactionRequest.  # noqa: E501

        Restrict the creation of the transactions from the outpoints provided ONLY (coin selection)  # noqa: E501

        :return: The selected_inputs of this CreateOnChainTransactionRequest.  # noqa: E501
        :rtype: list[str]
        """
        return self._selected_inputs

    @selected_inputs.setter
    def selected_inputs(self, selected_inputs):
        """Sets the selected_inputs of this CreateOnChainTransactionRequest.

        Restrict the creation of the transactions from the outpoints provided ONLY (coin selection)  # noqa: E501

        :param selected_inputs: The selected_inputs of this CreateOnChainTransactionRequest.  # noqa: E501
        :type: list[str]
        """

        self._selected_inputs = selected_inputs

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(CreateOnChainTransactionRequest, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, CreateOnChainTransactionRequest):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    BTCPay Greenfield API

    A full API to use your BTCPay Server  # noqa: E501

    OpenAPI spec version: v1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class PayoutProcessorData(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'name': 'str',
        'friendly_name': 'str',
        'payment_methods': 'list[str]'
    }

    attribute_map = {
        'name': 'name',
        'friendly_name': 'friendlyName',
        'payment_methods': 'paymentMethods'
    }

    def __init__(self, name=None, friendly_name=None, payment_methods=None):  # noqa: E501
        """PayoutProcessorData - a model defined in Swagger"""  # noqa: E501
        self._name = None
        self._friendly_name = None
        self._payment_methods = None
        self.discriminator = None
        if name is not None:
            self.name = name
        if friendly_name is not None:
            self.friendly_name = friendly_name
        if payment_methods is not None:
            self.payment_methods = payment_methods

    @property
    def name(self):
        """Gets the name of this PayoutProcessorData.  # noqa: E501

        unique identifier of the payout processor  # noqa: E501

        :return: The name of this PayoutProcessorData.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this PayoutProcessorData.

        unique identifier of the payout processor  # noqa: E501

        :param name: The name of this PayoutProcessorData.  # noqa: E501
        :type: str
        """

        self._name = name

    @property
    def friendly_name(self):
        """Gets the friendly_name of this PayoutProcessorData.  # noqa: E501

        Human name of the payout processor  # noqa: E501

        :return: The friendly_name of this PayoutProcessorData.  # noqa: E501
        :rtype: str
        """
        return self._friendly_name

    @friendly_name.setter
    def friendly_name(self, friendly_name):
        """Sets the friendly_name of this PayoutProcessorData.

        Human name of the payout processor  # noqa: E501

        :param friendly_name: The friendly_name of this PayoutProcessorData.  # noqa: E501
        :type: str
        """

        self._friendly_name = friendly_name

    @property
    def payment_methods(self):
        """Gets the payment_methods of this PayoutProcessorData.  # noqa: E501

        Supported, payment methods by this processor  # noqa: E501

        :return: The payment_methods of this PayoutProcessorData.  # noqa: E501
        :rtype: list[str]
        """
        return self._payment_methods

    @payment_methods.setter
    def payment_methods(self, payment_methods):
        """Sets the payment_methods of this PayoutProcessorData.

        Supported, payment methods by this processor  # noqa: E501

        :param payment_methods: The payment_methods of this PayoutProcessorData.  # noqa: E501
        :type: list[str]
        """

        self._payment_methods = payment_methods

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(PayoutProcessorData, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, PayoutProcessorData):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    BTCPay Greenfield API

    A full API to use your BTCPay Server  # noqa: E501

    OpenAPI spec version: v1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class LightningChannelData(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'remote_node': 'str',
        'is_public': 'bool',
        'is_active': 'bool',
        'capacity': 'str',
        'local_balance': 'str',
        'channel_point': 'str'
    }

    attribute_map = {
        'remote_node': 'remoteNode',
        'is_public': 'isPublic',
        'is_active': 'isActive',
        'capacity': 'capacity',
        'local_balance': 'localBalance',
        'channel_point': 'channelPoint'
    }

    def __init__(self, remote_node=None, is_public=None, is_active=None, capacity=None, local_balance=None, channel_point=None):  # noqa: E501
        """LightningChannelData - a model defined in Swagger"""  # noqa: E501
        self._remote_node = None
        self._is_public = None
        self._is_active = None
        self._capacity = None
        self._local_balance = None
        self._channel_point = None
        self.discriminator = None
        if remote_node is not None:
            self.remote_node = remote_node
        if is_public is not None:
            self.is_public = is_public
        if is_active is not None:
            self.is_active = is_active
        if capacity is not None:
            self.capacity = capacity
        if local_balance is not None:
            self.local_balance = local_balance
        if channel_point is not None:
            self.channel_point = channel_point

    @property
    def remote_node(self):
        """Gets the remote_node of this LightningChannelData.  # noqa: E501

        The public key of the node (Node ID)  # noqa: E501

        :return: The remote_node of this LightningChannelData.  # noqa: E501
        :rtype: str
        """
        return self._remote_node

    @remote_node.setter
    def remote_node(self, remote_node):
        """Sets the remote_node of this LightningChannelData.

        The public key of the node (Node ID)  # noqa: E501

        :param remote_node: The remote_node of this LightningChannelData.  # noqa: E501
        :type: str
        """

        self._remote_node = remote_node

    @property
    def is_public(self):
        """Gets the is_public of this LightningChannelData.  # noqa: E501

        Whether the node is public  # noqa: E501

        :return: The is_public of this LightningChannelData.  # noqa: E501
        :rtype: bool
        """
        return self._is_public

    @is_public.setter
    def is_public(self, is_public):
        """Sets the is_public of this LightningChannelData.

        Whether the node is public  # noqa: E501

        :param is_public: The is_public of this LightningChannelData.  # noqa: E501
        :type: bool
        """

        self._is_public = is_public

    @property
    def is_active(self):
        """Gets the is_active of this LightningChannelData.  # noqa: E501

        Whether the node is online  # noqa: E501

        :return: The is_active of this LightningChannelData.  # noqa: E501
        :rtype: bool
        """
        return self._is_active

    @is_active.setter
    def is_active(self, is_active):
        """Sets the is_active of this LightningChannelData.

        Whether the node is online  # noqa: E501

        :param is_active: The is_active of this LightningChannelData.  # noqa: E501
        :type: bool
        """

        self._is_active = is_active

    @property
    def capacity(self):
        """Gets the capacity of this LightningChannelData.  # noqa: E501

        The capacity of the channel in millisatoshi  # noqa: E501

        :return: The capacity of this LightningChannelData.  # noqa: E501
        :rtype: str
        """
        return self._capacity

    @capacity.setter
    def capacity(self, capacity):
        """Sets the capacity of this LightningChannelData.

        The capacity of the channel in millisatoshi  # noqa: E501

        :param capacity: The capacity of this LightningChannelData.  # noqa: E501
        :type: str
        """

        self._capacity = capacity

    @property
    def local_balance(self):
        """Gets the local_balance of this LightningChannelData.  # noqa: E501

        The local balance of the channel in millisatoshi  # noqa: E501

        :return: The local_balance of this LightningChannelData.  # noqa: E501
        :rtype: str
        """
        return self._local_balance

    @local_balance.setter
    def local_balance(self, local_balance):
        """Sets the local_balance of this LightningChannelData.

        The local balance of the channel in millisatoshi  # noqa: E501

        :param local_balance: The local_balance of this LightningChannelData.  # noqa: E501
        :type: str
        """

        self._local_balance = local_balance

    @property
    def channel_point(self):
        """Gets the channel_point of this LightningChannelData.  # noqa: E501


        :return: The channel_point of this LightningChannelData.  # noqa: E501
        :rtype: str
        """
        return self._channel_point

    @channel_point.setter
    def channel_point(self, channel_point):
        """Sets the channel_point of this LightningChannelData.


        :param channel_point: The channel_point of this LightningChannelData.  # noqa: E501
        :type: str
        """

        self._channel_point = channel_point

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(LightningChannelData, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, LightningChannelData):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    BTCPay Greenfield API

    A full API to use your BTCPay Server  # noqa: E501

    OpenAPI spec version: v1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class Payment(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'id': 'str',
        'received_date': 'AllOfPaymentReceivedDate',
        'value': 'str',
        'fee': 'str',
        'status': 'PaymentStatus',
        'destination': 'str'
    }

    attribute_map = {
        'id': 'id',
        'received_date': 'receivedDate',
        'value': 'value',
        'fee': 'fee',
        'status': 'status',
        'destination': 'destination'
    }

    def __init__(self, id=None, received_date=None, value=None, fee=None, status=None, destination=None):  # noqa: E501
        """Payment - a model defined in Swagger"""  # noqa: E501
        self._id = None
        self._received_date = None
        self._value = None
        self._fee = None
        self._status = None
        self._destination = None
        self.discriminator = None
        if id is not None:
            self.id = id
        if received_date is not None:
            self.received_date = received_date
        if value is not None:
            self.value = value
        if fee is not None:
            self.fee = fee
        if status is not None:
            self.status = status
        if destination is not None:
            self.destination = destination

    @property
    def id(self):
        """Gets the id of this Payment.  # noqa: E501

        A unique identifier for this payment  # noqa: E501

        :return: The id of this Payment.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this Payment.

        A unique identifier for this payment  # noqa: E501

        :param id: The id of this Payment.  # noqa: E501
        :type: str
        """

        self._id = id

    @property
    def received_date(self):
        """Gets the received_date of this Payment.  # noqa: E501

        The date the payment was recorded  # noqa: E501

        :return: The received_date of this Payment.  # noqa: E501
        :rtype: AllOfPaymentReceivedDate
        """
        return self._received_date

    @received_date.setter
    def received_date(self, received_date):
        """Sets the received_date of this Payment.

        The date the payment was recorded  # noqa: E501

        :param received_date: The received_date of this Payment.  # noqa: E501
        :type: AllOfPaymentReceivedDate
        """

        self._received_date = received_date

    @property
    def value(self):
        """Gets the value of this Payment.  # noqa: E501

        The value of the payment  # noqa: E501

        :return: The value of this Payment.  # noqa: E501
        :rtype: str
        """
        return self._value

    @value.setter
    def value(self, value):
        """Sets the value of this Payment.

        The value of the payment  # noqa: E501

        :param value: The value of this Payment.  # noqa: E501
        :type: str
        """

        self._value = value

    @property
    def fee(self):
        """Gets the fee of this Payment.  # noqa: E501

        The fee paid for the payment  # noqa: E501

        :return: The fee of this Payment.  # noqa: E501
        :rtype: str
        """
        return self._fee

    @fee.setter
    def fee(self, fee):
        """Sets the fee of this Payment.

        The fee paid for the payment  # noqa: E501

        :param fee: The fee of this Payment.  # noqa: E501
        :type: str
        """

        self._fee = fee

    @property
    def status(self):
        """Gets the status of this Payment.  # noqa: E501


        :return: The status of this Payment.  # noqa: E501
        :rtype: PaymentStatus
        """
        return self._status

    @status.setter
    def status(self, status):
        """Sets the status of this Payment.


        :param status: The status of this Payment.  # noqa: E501
        :type: PaymentStatus
        """

        self._status = status

    @property
    def destination(self):
        """Gets the destination of this Payment.  # noqa: E501

        The destination the payment was made to  # noqa: E501

        :return: The destination of this Payment.  # noqa: E501
        :rtype: str
        """
        return self._destination

    @destination.setter
    def destination(self, destination):
        """Sets the destination of this Payment.

        The destination the payment was made to  # noqa: E501

        :param destination: The destination of this Payment.  # noqa: E501
        :type: str
        """

        self._destination = destination

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(Payment, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, Payment):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    BTCPay Greenfield API

    A full API to use your BTCPay Server  # noqa: E501

    OpenAPI spec version: v1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

import unittest

import pygreenfield
from pygreenfield.api.stores__payout_processors_api import StoresPayoutProcessorsApi  # noqa: E501
from pygreenfield.rest import ApiException


class TestStoresPayoutProcessorsApi(unittest.TestCase):
    """StoresPayoutProcessorsApi unit test stubs"""

    def setUp(self):
        self.api = StoresPayoutProcessorsApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_greenfield_store_automated_lightning_payout_processors_controller_get_store_lightning_automated_payout_processors(self):
        """Test case for greenfield_store_automated_lightning_payout_processors_controller_get_store_lightning_automated_payout_processors

        Get configured store Lightning automated payout processors  # noqa: E501
        """
        pass

    def test_greenfield_store_automated_lightning_payout_processors_controller_get_store_lightning_automated_payout_processors_0(self):
        """Test case for greenfield_store_automated_lightning_payout_processors_controller_get_store_lightning_automated_payout_processors_0

        Get configured store Lightning automated payout processors  # noqa: E501
        """
        pass

    def test_greenfield_store_automated_lightning_payout_processors_controller_update_store_lightning_automated_payout_processor(self):
        """Test case for greenfield_store_automated_lightning_payout_processors_controller_update_store_lightning_automated_payout_processor

        Update configured store Lightning automated payout processors  # noqa: E501
        """
        pass

    def test_greenfield_store_automated_on_chain_payout_processors_controller_get_store_on_chain_automated_payout_processors(self):
        """Test case for greenfield_store_automated_on_chain_payout_processors_controller_get_store_on_chain_automated_payout_processors

        Get configured store onchain automated payout processors  # noqa: E501
        """
        pass

    def test_greenfield_store_automated_on_chain_payout_processors_controller_get_store_on_chain_automated_payout_processors_0(self):
        """Test case for greenfield_store_automated_on_chain_payout_processors_controller_get_store_on_chain_automated_payout_processors_0

        Get configured store onchain automated payout processors  # noqa: E501
        """
        pass

    def test_greenfield_store_automated_on_chain_payout_processors_controller_update_store_on_chain_automated_payout_processor(self):
        """Test case for greenfield_store_automated_on_chain_payout_processors_controller_update_store_on_chain_automated_payout_processor

        Update configured store onchain automated payout processors  # noqa: E501
        """
        pass

    def test_greenfield_store_automated_on_chain_payout_processors_controller_update_store_on_chain_automated_payout_processor_0(self):
        """Test case for greenfield_store_automated_on_chain_payout_processors_controller_update_store_on_chain_automated_payout_processor_0

        Update configured store onchain automated payout processors  # noqa: E501
        """
        pass

    def test_store_payout_processors_get_store_payout_processors(self):
        """Test case for store_payout_processors_get_store_payout_processors

        Get store configured payout processors  # noqa: E501
        """
        pass

    def test_store_payout_processors_remove_store_payout_processor(self):
        """Test case for store_payout_processors_remove_store_payout_processor

        Remove store configured payout processor  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    BTCPay Greenfield API

    A full API to use your BTCPay Server  # noqa: E501

    OpenAPI spec version: v1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class LightningInvoiceData(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'id': 'str',
        'status': 'LightningInvoiceStatus',
        'bolt11': 'str',
        'paid_at': 'AllOfLightningInvoiceDataPaidAt',
        'expires_at': 'AllOfLightningInvoiceDataExpiresAt',
        'amount': 'str',
        'amount_received': 'str'
    }

    attribute_map = {
        'id': 'id',
        'status': 'status',
        'bolt11': 'BOLT11',
        'paid_at': 'paidAt',
        'expires_at': 'expiresAt',
        'amount': 'amount',
        'amount_received': 'amountReceived'
    }

    def __init__(self, id=None, status=None, bolt11=None, paid_at=None, expires_at=None, amount=None, amount_received=None):  # noqa: E501
        """LightningInvoiceData - a model defined in Swagger"""  # noqa: E501
        self._id = None
        self._status = None
        self._bolt11 = None
        self._paid_at = None
        self._expires_at = None
        self._amount = None
        self._amount_received = None
        self.discriminator = None
        if id is not None:
            self.id = id
        if status is not None:
            self.status = status
        if bolt11 is not None:
            self.bolt11 = bolt11
        if paid_at is not None:
            self.paid_at = paid_at
        if expires_at is not None:
            self.expires_at = expires_at
        if amount is not None:
            self.amount = amount
        if amount_received is not None:
            self.amount_received = amount_received

    @property
    def id(self):
        """Gets the id of this LightningInvoiceData.  # noqa: E501

        The invoice's ID  # noqa: E501

        :return: The id of this LightningInvoiceData.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this LightningInvoiceData.

        The invoice's ID  # noqa: E501

        :param id: The id of this LightningInvoiceData.  # noqa: E501
        :type: str
        """

        self._id = id

    @property
    def status(self):
        """Gets the status of this LightningInvoiceData.  # noqa: E501


        :return: The status of this LightningInvoiceData.  # noqa: E501
        :rtype: LightningInvoiceStatus
        """
        return self._status

    @status.setter
    def status(self, status):
        """Sets the status of this LightningInvoiceData.


        :param status: The status of this LightningInvoiceData.  # noqa: E501
        :type: LightningInvoiceStatus
        """

        self._status = status

    @property
    def bolt11(self):
        """Gets the bolt11 of this LightningInvoiceData.  # noqa: E501

        The BOLT11 representation of the invoice  # noqa: E501

        :return: The bolt11 of this LightningInvoiceData.  # noqa: E501
        :rtype: str
        """
        return self._bolt11

    @bolt11.setter
    def bolt11(self, bolt11):
        """Sets the bolt11 of this LightningInvoiceData.

        The BOLT11 representation of the invoice  # noqa: E501

        :param bolt11: The bolt11 of this LightningInvoiceData.  # noqa: E501
        :type: str
        """

        self._bolt11 = bolt11

    @property
    def paid_at(self):
        """Gets the paid_at of this LightningInvoiceData.  # noqa: E501

        The unix timestamp when the invoice got paid  # noqa: E501

        :return: The paid_at of this LightningInvoiceData.  # noqa: E501
        :rtype: AllOfLightningInvoiceDataPaidAt
        """
        return self._paid_at

    @paid_at.setter
    def paid_at(self, paid_at):
        """Sets the paid_at of this LightningInvoiceData.

        The unix timestamp when the invoice got paid  # noqa: E501

        :param paid_at: The paid_at of this LightningInvoiceData.  # noqa: E501
        :type: AllOfLightningInvoiceDataPaidAt
        """

        self._paid_at = paid_at

    @property
    def expires_at(self):
        """Gets the expires_at of this LightningInvoiceData.  # noqa: E501

        The unix timestamp when the invoice expires  # noqa: E501

        :return: The expires_at of this LightningInvoiceData.  # noqa: E501
        :rtype: AllOfLightningInvoiceDataExpiresAt
        """
        return self._expires_at

    @expires_at.setter
    def expires_at(self, expires_at):
        """Sets the expires_at of this LightningInvoiceData.

        The unix timestamp when the invoice expires  # noqa: E501

        :param expires_at: The expires_at of this LightningInvoiceData.  # noqa: E501
        :type: AllOfLightningInvoiceDataExpiresAt
        """

        self._expires_at = expires_at

    @property
    def amount(self):
        """Gets the amount of this LightningInvoiceData.  # noqa: E501

        The amount of the invoice in millisatoshi  # noqa: E501

        :return: The amount of this LightningInvoiceData.  # noqa: E501
        :rtype: str
        """
        return self._amount

    @amount.setter
    def amount(self, amount):
        """Sets the amount of this LightningInvoiceData.

        The amount of the invoice in millisatoshi  # noqa: E501

        :param amount: The amount of this LightningInvoiceData.  # noqa: E501
        :type: str
        """

        self._amount = amount

    @property
    def amount_received(self):
        """Gets the amount_received of this LightningInvoiceData.  # noqa: E501

        The amount received in millisatoshi  # noqa: E501

        :return: The amount_received of this LightningInvoiceData.  # noqa: E501
        :rtype: str
        """
        return self._amount_received

    @amount_received.setter
    def amount_received(self, amount_received):
        """Sets the amount_received of this LightningInvoiceData.

        The amount received in millisatoshi  # noqa: E501

        :param amount_received: The amount_received of this LightningInvoiceData.  # noqa: E501
        :type: str
        """

        self._amount_received = amount_received

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(LightningInvoiceData, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, LightningInvoiceData):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    BTCPay Greenfield API

    A full API to use your BTCPay Server  # noqa: E501

    OpenAPI spec version: v1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

import unittest

import pygreenfield
from pygreenfield.api.stores__users_api import StoresUsersApi  # noqa: E501
from pygreenfield.rest import ApiException


class TestStoresUsersApi(unittest.TestCase):
    """StoresUsersApi unit test stubs"""

    def setUp(self):
        self.api = StoresUsersApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_stores_add_store_user(self):
        """Test case for stores_add_store_user

        Add a store user  # noqa: E501
        """
        pass

    def test_stores_get_store_users(self):
        """Test case for stores_get_store_users

        Get store users  # noqa: E501
        """
        pass

    def test_stores_remove_store_user(self):
        """Test case for stores_remove_store_user

        Remove Store User  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    BTCPay Greenfield API

    A full API to use your BTCPay Server  # noqa: E501

    OpenAPI spec version: v1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

import re  # noqa: F401

# python 2 and python 3 compatibility library
import six

from pygreenfield.api_client import ApiClient


class UsersApi(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    Ref: https://github.com/swagger-api/swagger-codegen
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

    def api_v1_users_get(self, **kwargs):  # noqa: E501
        """Get all users  # noqa: E501

        Load all users that exist.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.api_v1_users_get(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.api_v1_users_get_with_http_info(**kwargs)  # noqa: E501
        else:
            (data) = self.api_v1_users_get_with_http_info(**kwargs)  # noqa: E501
            return data

    def api_v1_users_get_with_http_info(self, **kwargs):  # noqa: E501
        """Get all users  # noqa: E501

        Load all users that exist.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.api_v1_users_get_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = []  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method api_v1_users_get" % key
                )
            params[key] = val
        del params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # Authentication setting
        auth_settings = ['API_Key']  # noqa: E501

        return self.api_client.call_api(
            '/api/v1/users', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type=None,  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def api_v1_users_id_or_email_delete(self, user_id, **kwargs):  # noqa: E501
        """Delete user  # noqa: E501

        Delete a user.  Must be an admin to perform this operation.  Attempting to delete the only admin user will not succeed.  All data associated with the user will be deleted as well if the operation succeeds.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.api_v1_users_id_or_email_delete(user_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str user_id: The ID of the user to be deleted (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.api_v1_users_id_or_email_delete_with_http_info(user_id, **kwargs)  # noqa: E501
        else:
            (data) = self.api_v1_users_id_or_email_delete_with_http_info(user_id, **kwargs)  # noqa: E501
            return data

    def api_v1_users_id_or_email_delete_with_http_info(self, user_id, **kwargs):  # noqa: E501
        """Delete user  # noqa: E501

        Delete a user.  Must be an admin to perform this operation.  Attempting to delete the only admin user will not succeed.  All data associated with the user will be deleted as well if the operation succeeds.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.api_v1_users_id_or_email_delete_with_http_info(user_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str user_id: The ID of the user to be deleted (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['user_id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method api_v1_users_id_or_email_delete" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'user_id' is set
        if ('user_id' not in params or
                params['user_id'] is None):
            raise ValueError("Missing the required parameter `user_id` when calling `api_v1_users_id_or_email_delete`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'user_id' in params:
            path_params['userId'] = params['user_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # Authentication setting
        auth_settings = ['API_Key']  # noqa: E501

        return self.api_client.call_api(
            '/api/v1/users/{idOrEmail}', 'DELETE',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type=None,  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def api_v1_users_id_or_email_get(self, id_or_email, **kwargs):  # noqa: E501
        """Get user by ID or Email  # noqa: E501

        Get 1 user by ID or Email.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.api_v1_users_id_or_email_get(id_or_email, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str id_or_email: The ID or email of the user to load (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.api_v1_users_id_or_email_get_with_http_info(id_or_email, **kwargs)  # noqa: E501
        else:
            (data) = self.api_v1_users_id_or_email_get_with_http_info(id_or_email, **kwargs)  # noqa: E501
            return data

    def api_v1_users_id_or_email_get_with_http_info(self, id_or_email, **kwargs):  # noqa: E501
        """Get user by ID or Email  # noqa: E501

        Get 1 user by ID or Email.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.api_v1_users_id_or_email_get_with_http_info(id_or_email, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str id_or_email: The ID or email of the user to load (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['id_or_email']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method api_v1_users_id_or_email_get" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'id_or_email' is set
        if ('id_or_email' not in params or
                params['id_or_email'] is None):
            raise ValueError("Missing the required parameter `id_or_email` when calling `api_v1_users_id_or_email_get`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'id_or_email' in params:
            path_params['idOrEmail'] = params['id_or_email']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # Authentication setting
        auth_settings = ['API_Key']  # noqa: E501

        return self.api_client.call_api(
            '/api/v1/users/{idOrEmail}', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type=None,  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def api_v1_users_id_or_email_lock_delete(self, user_id, **kwargs):  # noqa: E501
        """Toggle user  # noqa: E501

        Lock or unlock a user.  Must be an admin to perform this operation.  Attempting to lock the only admin user will not succeed.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.api_v1_users_id_or_email_lock_delete(user_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str user_id: The ID of the user to be un/locked (required)
        :param LockUserRequest body:
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.api_v1_users_id_or_email_lock_delete_with_http_info(user_id, **kwargs)  # noqa: E501
        else:
            (data) = self.api_v1_users_id_or_email_lock_delete_with_http_info(user_id, **kwargs)  # noqa: E501
            return data

    def api_v1_users_id_or_email_lock_delete_with_http_info(self, user_id, **kwargs):  # noqa: E501
        """Toggle user  # noqa: E501

        Lock or unlock a user.  Must be an admin to perform this operation.  Attempting to lock the only admin user will not succeed.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.api_v1_users_id_or_email_lock_delete_with_http_info(user_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str user_id: The ID of the user to be un/locked (required)
        :param LockUserRequest body:
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['user_id', 'body']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method api_v1_users_id_or_email_lock_delete" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'user_id' is set
        if ('user_id' not in params or
                params['user_id'] is None):
            raise ValueError("Missing the required parameter `user_id` when calling `api_v1_users_id_or_email_lock_delete`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'user_id' in params:
            path_params['userId'] = params['user_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['API_Key']  # noqa: E501

        return self.api_client.call_api(
            '/api/v1/users/{idOrEmail}/lock', 'DELETE',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type=None,  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def api_v1_users_post(self, body, **kwargs):  # noqa: E501
        """Create user  # noqa: E501

        Create a new user.  This operation can be called without authentication in any of this cases: * There is not any administrator yet on the server, * The subscriptions are not disabled in the server's policies.  If the first administrator is created by this call, subscriptions are automatically disabled.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.api_v1_users_post(body, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param V1UsersBody body: (required)
        :return: ApplicationUserData
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.api_v1_users_post_with_http_info(body, **kwargs)  # noqa: E501
        else:
            (data) = self.api_v1_users_post_with_http_info(body, **kwargs)  # noqa: E501
            return data

    def api_v1_users_post_with_http_info(self, body, **kwargs):  # noqa: E501
        """Create user  # noqa: E501

        Create a new user.  This operation can be called without authentication in any of this cases: * There is not any administrator yet on the server, * The subscriptions are not disabled in the server's policies.  If the first administrator is created by this call, subscriptions are automatically disabled.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.api_v1_users_post_with_http_info(body, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param V1UsersBody body: (required)
        :return: ApplicationUserData
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['body']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method api_v1_users_post" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'body' is set
        if ('body' not in params or
                params['body'] is None):
            raise ValueError("Missing the required parameter `body` when calling `api_v1_users_post`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['API_Key']  # noqa: E501

        return self.api_client.call_api(
            '/api/v1/users', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='ApplicationUserData',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def users_delete_current_user(self, **kwargs):  # noqa: E501
        """Deletes user profile  # noqa: E501

        Deletes user profile and associated user data for user making the request  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.users_delete_current_user(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.users_delete_current_user_with_http_info(**kwargs)  # noqa: E501
        else:
            (data) = self.users_delete_current_user_with_http_info(**kwargs)  # noqa: E501
            return data

    def users_delete_current_user_with_http_info(self, **kwargs):  # noqa: E501
        """Deletes user profile  # noqa: E501

        Deletes user profile and associated user data for user making the request  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.users_delete_current_user_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = []  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method users_delete_current_user" % key
                )
            params[key] = val
        del params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # Authentication setting
        auth_settings = ['API_Key']  # noqa: E501

        return self.api_client.call_api(
            '/api/v1/users/me', 'DELETE',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type=None,  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def users_get_current_user(self, **kwargs):  # noqa: E501
        """Get current user information  # noqa: E501

        View information about the current user  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.users_get_current_user(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :return: ApplicationUserData
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.users_get_current_user_with_http_info(**kwargs)  # noqa: E501
        else:
            (data) = self.users_get_current_user_with_http_info(**kwargs)  # noqa: E501
            return data

    def users_get_current_user_with_http_info(self, **kwargs):  # noqa: E501
        """Get current user information  # noqa: E501

        View information about the current user  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.users_get_current_user_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :return: ApplicationUserData
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = []  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method users_get_current_user" % key
                )
            params[key] = val
        del params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['API_Key']  # noqa: E501

        return self.api_client.call_api(
            '/api/v1/users/me', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='ApplicationUserData',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)



# coding: utf-8

"""
    BTCPay Greenfield API

    A full API to use your BTCPay Server  # noqa: E501

    OpenAPI spec version: v1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class ApplicationServerInfoSyncStatusData(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'crypto_code': 'str',
        'node_information': 'ApplicationServerInfoNodeStatusData',
        'chain_height': 'int',
        'sync_height': 'float',
        'available': 'bool'
    }

    attribute_map = {
        'crypto_code': 'cryptoCode',
        'node_information': 'nodeInformation',
        'chain_height': 'chainHeight',
        'sync_height': 'syncHeight',
        'available': 'available'
    }

    def __init__(self, crypto_code=None, node_information=None, chain_height=None, sync_height=None, available=None):  # noqa: E501
        """ApplicationServerInfoSyncStatusData - a model defined in Swagger"""  # noqa: E501
        self._crypto_code = None
        self._node_information = None
        self._chain_height = None
        self._sync_height = None
        self._available = None
        self.discriminator = None
        if crypto_code is not None:
            self.crypto_code = crypto_code
        if node_information is not None:
            self.node_information = node_information
        if chain_height is not None:
            self.chain_height = chain_height
        if sync_height is not None:
            self.sync_height = sync_height
        if available is not None:
            self.available = available

    @property
    def crypto_code(self):
        """Gets the crypto_code of this ApplicationServerInfoSyncStatusData.  # noqa: E501

        The CryptoCode of the crypto currency (eg. BTC)  # noqa: E501

        :return: The crypto_code of this ApplicationServerInfoSyncStatusData.  # noqa: E501
        :rtype: str
        """
        return self._crypto_code

    @crypto_code.setter
    def crypto_code(self, crypto_code):
        """Sets the crypto_code of this ApplicationServerInfoSyncStatusData.

        The CryptoCode of the crypto currency (eg. BTC)  # noqa: E501

        :param crypto_code: The crypto_code of this ApplicationServerInfoSyncStatusData.  # noqa: E501
        :type: str
        """

        self._crypto_code = crypto_code

    @property
    def node_information(self):
        """Gets the node_information of this ApplicationServerInfoSyncStatusData.  # noqa: E501


        :return: The node_information of this ApplicationServerInfoSyncStatusData.  # noqa: E501
        :rtype: ApplicationServerInfoNodeStatusData
        """
        return self._node_information

    @node_information.setter
    def node_information(self, node_information):
        """Sets the node_information of this ApplicationServerInfoSyncStatusData.


        :param node_information: The node_information of this ApplicationServerInfoSyncStatusData.  # noqa: E501
        :type: ApplicationServerInfoNodeStatusData
        """

        self._node_information = node_information

    @property
    def chain_height(self):
        """Gets the chain_height of this ApplicationServerInfoSyncStatusData.  # noqa: E501

        The height of the chain of header of the internal indexer  # noqa: E501

        :return: The chain_height of this ApplicationServerInfoSyncStatusData.  # noqa: E501
        :rtype: int
        """
        return self._chain_height

    @chain_height.setter
    def chain_height(self, chain_height):
        """Sets the chain_height of this ApplicationServerInfoSyncStatusData.

        The height of the chain of header of the internal indexer  # noqa: E501

        :param chain_height: The chain_height of this ApplicationServerInfoSyncStatusData.  # noqa: E501
        :type: int
        """

        self._chain_height = chain_height

    @property
    def sync_height(self):
        """Gets the sync_height of this ApplicationServerInfoSyncStatusData.  # noqa: E501

        The height of the latest indexed block of the internal indexer  # noqa: E501

        :return: The sync_height of this ApplicationServerInfoSyncStatusData.  # noqa: E501
        :rtype: float
        """
        return self._sync_height

    @sync_height.setter
    def sync_height(self, sync_height):
        """Sets the sync_height of this ApplicationServerInfoSyncStatusData.

        The height of the latest indexed block of the internal indexer  # noqa: E501

        :param sync_height: The sync_height of this ApplicationServerInfoSyncStatusData.  # noqa: E501
        :type: float
        """

        self._sync_height = sync_height

    @property
    def available(self):
        """Gets the available of this ApplicationServerInfoSyncStatusData.  # noqa: E501

        True if the full node and the indexer are fully synchronized  # noqa: E501

        :return: The available of this ApplicationServerInfoSyncStatusData.  # noqa: E501
        :rtype: bool
        """
        return self._available

    @available.setter
    def available(self, available):
        """Sets the available of this ApplicationServerInfoSyncStatusData.

        True if the full node and the indexer are fully synchronized  # noqa: E501

        :param available: The available of this ApplicationServerInfoSyncStatusData.  # noqa: E501
        :type: bool
        """

        self._available = available

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(ApplicationServerInfoSyncStatusData, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ApplicationServerInfoSyncStatusData):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    BTCPay Greenfield API

    A full API to use your BTCPay Server  # noqa: E501

    OpenAPI spec version: v1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class CreateLightningInvoiceRequest(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'amount': 'str',
        'description': 'str',
        'description_hash': 'str',
        'expiry': 'AllOfCreateLightningInvoiceRequestExpiry',
        'private_route_hints': 'bool'
    }

    attribute_map = {
        'amount': 'amount',
        'description': 'description',
        'description_hash': 'descriptionHash',
        'expiry': 'expiry',
        'private_route_hints': 'privateRouteHints'
    }

    def __init__(self, amount=None, description=None, description_hash=None, expiry=None, private_route_hints=False):  # noqa: E501
        """CreateLightningInvoiceRequest - a model defined in Swagger"""  # noqa: E501
        self._amount = None
        self._description = None
        self._description_hash = None
        self._expiry = None
        self._private_route_hints = None
        self.discriminator = None
        if amount is not None:
            self.amount = amount
        if description is not None:
            self.description = description
        if description_hash is not None:
            self.description_hash = description_hash
        if expiry is not None:
            self.expiry = expiry
        if private_route_hints is not None:
            self.private_route_hints = private_route_hints

    @property
    def amount(self):
        """Gets the amount of this CreateLightningInvoiceRequest.  # noqa: E501

        Amount wrapped in a string, represented in a millistatoshi string. (1000 millisatoshi = 1 satoshi)  # noqa: E501

        :return: The amount of this CreateLightningInvoiceRequest.  # noqa: E501
        :rtype: str
        """
        return self._amount

    @amount.setter
    def amount(self, amount):
        """Sets the amount of this CreateLightningInvoiceRequest.

        Amount wrapped in a string, represented in a millistatoshi string. (1000 millisatoshi = 1 satoshi)  # noqa: E501

        :param amount: The amount of this CreateLightningInvoiceRequest.  # noqa: E501
        :type: str
        """

        self._amount = amount

    @property
    def description(self):
        """Gets the description of this CreateLightningInvoiceRequest.  # noqa: E501

        Description of the invoice in the BOLT11  # noqa: E501

        :return: The description of this CreateLightningInvoiceRequest.  # noqa: E501
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """Sets the description of this CreateLightningInvoiceRequest.

        Description of the invoice in the BOLT11  # noqa: E501

        :param description: The description of this CreateLightningInvoiceRequest.  # noqa: E501
        :type: str
        """

        self._description = description

    @property
    def description_hash(self):
        """Gets the description_hash of this CreateLightningInvoiceRequest.  # noqa: E501

        Description hash of the invoice in the BOLT11  # noqa: E501

        :return: The description_hash of this CreateLightningInvoiceRequest.  # noqa: E501
        :rtype: str
        """
        return self._description_hash

    @description_hash.setter
    def description_hash(self, description_hash):
        """Sets the description_hash of this CreateLightningInvoiceRequest.

        Description hash of the invoice in the BOLT11  # noqa: E501

        :param description_hash: The description_hash of this CreateLightningInvoiceRequest.  # noqa: E501
        :type: str
        """

        self._description_hash = description_hash

    @property
    def expiry(self):
        """Gets the expiry of this CreateLightningInvoiceRequest.  # noqa: E501

        Expiration time in seconds  # noqa: E501

        :return: The expiry of this CreateLightningInvoiceRequest.  # noqa: E501
        :rtype: AllOfCreateLightningInvoiceRequestExpiry
        """
        return self._expiry

    @expiry.setter
    def expiry(self, expiry):
        """Sets the expiry of this CreateLightningInvoiceRequest.

        Expiration time in seconds  # noqa: E501

        :param expiry: The expiry of this CreateLightningInvoiceRequest.  # noqa: E501
        :type: AllOfCreateLightningInvoiceRequestExpiry
        """

        self._expiry = expiry

    @property
    def private_route_hints(self):
        """Gets the private_route_hints of this CreateLightningInvoiceRequest.  # noqa: E501

        True if the invoice should include private route hints  # noqa: E501

        :return: The private_route_hints of this CreateLightningInvoiceRequest.  # noqa: E501
        :rtype: bool
        """
        return self._private_route_hints

    @private_route_hints.setter
    def private_route_hints(self, private_route_hints):
        """Sets the private_route_hints of this CreateLightningInvoiceRequest.

        True if the invoice should include private route hints  # noqa: E501

        :param private_route_hints: The private_route_hints of this CreateLightningInvoiceRequest.  # noqa: E501
        :type: bool
        """

        self._private_route_hints = private_route_hints

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(CreateLightningInvoiceRequest, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, CreateLightningInvoiceRequest):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    BTCPay Greenfield API

    A full API to use your BTCPay Server  # noqa: E501

    OpenAPI spec version: v1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class StoreBaseData(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'name': 'str',
        'website': 'str',
        'default_currency': 'str',
        'invoice_expiration': 'AllOfStoreBaseDataInvoiceExpiration',
        'monitoring_expiration': 'AllOfStoreBaseDataMonitoringExpiration',
        'speed_policy': 'SpeedPolicy',
        'lightning_description_template': 'str',
        'payment_tolerance': 'float',
        'anyone_can_create_invoice': 'bool',
        'requires_refund_email': 'bool',
        'receipt': 'ReceiptOptions',
        'lightning_amount_in_satoshi': 'bool',
        'lightning_private_route_hints': 'bool',
        'on_chain_with_ln_invoice_fallback': 'bool',
        'redirect_automatically': 'bool',
        'show_recommended_fee': 'bool',
        'recommended_fee_block_target': 'int',
        'default_lang': 'str',
        'custom_logo': 'str',
        'custom_css': 'str',
        'html_title': 'str',
        'network_fee_mode': 'NetworkFeeMode',
        'pay_join_enabled': 'bool',
        'lazy_payment_methods': 'bool',
        'default_payment_method': 'str'
    }

    attribute_map = {
        'name': 'name',
        'website': 'website',
        'default_currency': 'defaultCurrency',
        'invoice_expiration': 'invoiceExpiration',
        'monitoring_expiration': 'monitoringExpiration',
        'speed_policy': 'speedPolicy',
        'lightning_description_template': 'lightningDescriptionTemplate',
        'payment_tolerance': 'paymentTolerance',
        'anyone_can_create_invoice': 'anyoneCanCreateInvoice',
        'requires_refund_email': 'requiresRefundEmail',
        'receipt': 'receipt',
        'lightning_amount_in_satoshi': 'lightningAmountInSatoshi',
        'lightning_private_route_hints': 'lightningPrivateRouteHints',
        'on_chain_with_ln_invoice_fallback': 'onChainWithLnInvoiceFallback',
        'redirect_automatically': 'redirectAutomatically',
        'show_recommended_fee': 'showRecommendedFee',
        'recommended_fee_block_target': 'recommendedFeeBlockTarget',
        'default_lang': 'defaultLang',
        'custom_logo': 'customLogo',
        'custom_css': 'customCSS',
        'html_title': 'htmlTitle',
        'network_fee_mode': 'networkFeeMode',
        'pay_join_enabled': 'payJoinEnabled',
        'lazy_payment_methods': 'lazyPaymentMethods',
        'default_payment_method': 'defaultPaymentMethod'
    }

    def __init__(self, name=None, website=None, default_currency='USD', invoice_expiration=None, monitoring_expiration=None, speed_policy=None, lightning_description_template=None, payment_tolerance=0, anyone_can_create_invoice=False, requires_refund_email=False, receipt=None, lightning_amount_in_satoshi=False, lightning_private_route_hints=False, on_chain_with_ln_invoice_fallback=False, redirect_automatically=False, show_recommended_fee=True, recommended_fee_block_target=1, default_lang='en', custom_logo=None, custom_css=None, html_title=None, network_fee_mode=None, pay_join_enabled=False, lazy_payment_methods=False, default_payment_method=None):  # noqa: E501
        """StoreBaseData - a model defined in Swagger"""  # noqa: E501
        self._name = None
        self._website = None
        self._default_currency = None
        self._invoice_expiration = None
        self._monitoring_expiration = None
        self._speed_policy = None
        self._lightning_description_template = None
        self._payment_tolerance = None
        self._anyone_can_create_invoice = None
        self._requires_refund_email = None
        self._receipt = None
        self._lightning_amount_in_satoshi = None
        self._lightning_private_route_hints = None
        self._on_chain_with_ln_invoice_fallback = None
        self._redirect_automatically = None
        self._show_recommended_fee = None
        self._recommended_fee_block_target = None
        self._default_lang = None
        self._custom_logo = None
        self._custom_css = None
        self._html_title = None
        self._network_fee_mode = None
        self._pay_join_enabled = None
        self._lazy_payment_methods = None
        self._default_payment_method = None
        self.discriminator = None
        if name is not None:
            self.name = name
        if website is not None:
            self.website = website
        if default_currency is not None:
            self.default_currency = default_currency
        if invoice_expiration is not None:
            self.invoice_expiration = invoice_expiration
        if monitoring_expiration is not None:
            self.monitoring_expiration = monitoring_expiration
        if speed_policy is not None:
            self.speed_policy = speed_policy
        if lightning_description_template is not None:
            self.lightning_description_template = lightning_description_template
        if payment_tolerance is not None:
            self.payment_tolerance = payment_tolerance
        if anyone_can_create_invoice is not None:
            self.anyone_can_create_invoice = anyone_can_create_invoice
        if requires_refund_email is not None:
            self.requires_refund_email = requires_refund_email
        if receipt is not None:
            self.receipt = receipt
        if lightning_amount_in_satoshi is not None:
            self.lightning_amount_in_satoshi = lightning_amount_in_satoshi
        if lightning_private_route_hints is not None:
            self.lightning_private_route_hints = lightning_private_route_hints
        if on_chain_with_ln_invoice_fallback is not None:
            self.on_chain_with_ln_invoice_fallback = on_chain_with_ln_invoice_fallback
        if redirect_automatically is not None:
            self.redirect_automatically = redirect_automatically
        if show_recommended_fee is not None:
            self.show_recommended_fee = show_recommended_fee
        if recommended_fee_block_target is not None:
            self.recommended_fee_block_target = recommended_fee_block_target
        if default_lang is not None:
            self.default_lang = default_lang
        if custom_logo is not None:
            self.custom_logo = custom_logo
        if custom_css is not None:
            self.custom_css = custom_css
        if html_title is not None:
            self.html_title = html_title
        if network_fee_mode is not None:
            self.network_fee_mode = network_fee_mode
        if pay_join_enabled is not None:
            self.pay_join_enabled = pay_join_enabled
        if lazy_payment_methods is not None:
            self.lazy_payment_methods = lazy_payment_methods
        if default_payment_method is not None:
            self.default_payment_method = default_payment_method

    @property
    def name(self):
        """Gets the name of this StoreBaseData.  # noqa: E501

        The name of the store  # noqa: E501

        :return: The name of this StoreBaseData.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this StoreBaseData.

        The name of the store  # noqa: E501

        :param name: The name of this StoreBaseData.  # noqa: E501
        :type: str
        """

        self._name = name

    @property
    def website(self):
        """Gets the website of this StoreBaseData.  # noqa: E501

        The absolute url of the store  # noqa: E501

        :return: The website of this StoreBaseData.  # noqa: E501
        :rtype: str
        """
        return self._website

    @website.setter
    def website(self, website):
        """Sets the website of this StoreBaseData.

        The absolute url of the store  # noqa: E501

        :param website: The website of this StoreBaseData.  # noqa: E501
        :type: str
        """

        self._website = website

    @property
    def default_currency(self):
        """Gets the default_currency of this StoreBaseData.  # noqa: E501

        The default currency of the store  # noqa: E501

        :return: The default_currency of this StoreBaseData.  # noqa: E501
        :rtype: str
        """
        return self._default_currency

    @default_currency.setter
    def default_currency(self, default_currency):
        """Sets the default_currency of this StoreBaseData.

        The default currency of the store  # noqa: E501

        :param default_currency: The default_currency of this StoreBaseData.  # noqa: E501
        :type: str
        """

        self._default_currency = default_currency

    @property
    def invoice_expiration(self):
        """Gets the invoice_expiration of this StoreBaseData.  # noqa: E501

        The time after which an invoice is considered expired if not paid. The value will be rounded down to a minute.  # noqa: E501

        :return: The invoice_expiration of this StoreBaseData.  # noqa: E501
        :rtype: AllOfStoreBaseDataInvoiceExpiration
        """
        return self._invoice_expiration

    @invoice_expiration.setter
    def invoice_expiration(self, invoice_expiration):
        """Sets the invoice_expiration of this StoreBaseData.

        The time after which an invoice is considered expired if not paid. The value will be rounded down to a minute.  # noqa: E501

        :param invoice_expiration: The invoice_expiration of this StoreBaseData.  # noqa: E501
        :type: AllOfStoreBaseDataInvoiceExpiration
        """

        self._invoice_expiration = invoice_expiration

    @property
    def monitoring_expiration(self):
        """Gets the monitoring_expiration of this StoreBaseData.  # noqa: E501

        The time after which an invoice which has been paid but not confirmed will be considered invalid. The value will be rounded down to a minute.  # noqa: E501

        :return: The monitoring_expiration of this StoreBaseData.  # noqa: E501
        :rtype: AllOfStoreBaseDataMonitoringExpiration
        """
        return self._monitoring_expiration

    @monitoring_expiration.setter
    def monitoring_expiration(self, monitoring_expiration):
        """Sets the monitoring_expiration of this StoreBaseData.

        The time after which an invoice which has been paid but not confirmed will be considered invalid. The value will be rounded down to a minute.  # noqa: E501

        :param monitoring_expiration: The monitoring_expiration of this StoreBaseData.  # noqa: E501
        :type: AllOfStoreBaseDataMonitoringExpiration
        """

        self._monitoring_expiration = monitoring_expiration

    @property
    def speed_policy(self):
        """Gets the speed_policy of this StoreBaseData.  # noqa: E501


        :return: The speed_policy of this StoreBaseData.  # noqa: E501
        :rtype: SpeedPolicy
        """
        return self._speed_policy

    @speed_policy.setter
    def speed_policy(self, speed_policy):
        """Sets the speed_policy of this StoreBaseData.


        :param speed_policy: The speed_policy of this StoreBaseData.  # noqa: E501
        :type: SpeedPolicy
        """

        self._speed_policy = speed_policy

    @property
    def lightning_description_template(self):
        """Gets the lightning_description_template of this StoreBaseData.  # noqa: E501

        The BOLT11 description of the lightning invoice in the checkout. You can use placeholders '{StoreName}', '{ItemDescription}' and '{OrderId}'.  # noqa: E501

        :return: The lightning_description_template of this StoreBaseData.  # noqa: E501
        :rtype: str
        """
        return self._lightning_description_template

    @lightning_description_template.setter
    def lightning_description_template(self, lightning_description_template):
        """Sets the lightning_description_template of this StoreBaseData.

        The BOLT11 description of the lightning invoice in the checkout. You can use placeholders '{StoreName}', '{ItemDescription}' and '{OrderId}'.  # noqa: E501

        :param lightning_description_template: The lightning_description_template of this StoreBaseData.  # noqa: E501
        :type: str
        """

        self._lightning_description_template = lightning_description_template

    @property
    def payment_tolerance(self):
        """Gets the payment_tolerance of this StoreBaseData.  # noqa: E501

        Consider an invoice fully paid, even if the payment is missing 'x' % of the full amount.  # noqa: E501

        :return: The payment_tolerance of this StoreBaseData.  # noqa: E501
        :rtype: float
        """
        return self._payment_tolerance

    @payment_tolerance.setter
    def payment_tolerance(self, payment_tolerance):
        """Sets the payment_tolerance of this StoreBaseData.

        Consider an invoice fully paid, even if the payment is missing 'x' % of the full amount.  # noqa: E501

        :param payment_tolerance: The payment_tolerance of this StoreBaseData.  # noqa: E501
        :type: float
        """

        self._payment_tolerance = payment_tolerance

    @property
    def anyone_can_create_invoice(self):
        """Gets the anyone_can_create_invoice of this StoreBaseData.  # noqa: E501

        If true, then no authentication is needed to create invoices on this store.  # noqa: E501

        :return: The anyone_can_create_invoice of this StoreBaseData.  # noqa: E501
        :rtype: bool
        """
        return self._anyone_can_create_invoice

    @anyone_can_create_invoice.setter
    def anyone_can_create_invoice(self, anyone_can_create_invoice):
        """Sets the anyone_can_create_invoice of this StoreBaseData.

        If true, then no authentication is needed to create invoices on this store.  # noqa: E501

        :param anyone_can_create_invoice: The anyone_can_create_invoice of this StoreBaseData.  # noqa: E501
        :type: bool
        """

        self._anyone_can_create_invoice = anyone_can_create_invoice

    @property
    def requires_refund_email(self):
        """Gets the requires_refund_email of this StoreBaseData.  # noqa: E501

        If true, the checkout page will ask to enter an email address before accessing payment information.  # noqa: E501

        :return: The requires_refund_email of this StoreBaseData.  # noqa: E501
        :rtype: bool
        """
        return self._requires_refund_email

    @requires_refund_email.setter
    def requires_refund_email(self, requires_refund_email):
        """Sets the requires_refund_email of this StoreBaseData.

        If true, the checkout page will ask to enter an email address before accessing payment information.  # noqa: E501

        :param requires_refund_email: The requires_refund_email of this StoreBaseData.  # noqa: E501
        :type: bool
        """

        self._requires_refund_email = requires_refund_email

    @property
    def receipt(self):
        """Gets the receipt of this StoreBaseData.  # noqa: E501


        :return: The receipt of this StoreBaseData.  # noqa: E501
        :rtype: ReceiptOptions
        """
        return self._receipt

    @receipt.setter
    def receipt(self, receipt):
        """Sets the receipt of this StoreBaseData.


        :param receipt: The receipt of this StoreBaseData.  # noqa: E501
        :type: ReceiptOptions
        """

        self._receipt = receipt

    @property
    def lightning_amount_in_satoshi(self):
        """Gets the lightning_amount_in_satoshi of this StoreBaseData.  # noqa: E501

        If true, lightning payment methods show amount in satoshi in the checkout page.  # noqa: E501

        :return: The lightning_amount_in_satoshi of this StoreBaseData.  # noqa: E501
        :rtype: bool
        """
        return self._lightning_amount_in_satoshi

    @lightning_amount_in_satoshi.setter
    def lightning_amount_in_satoshi(self, lightning_amount_in_satoshi):
        """Sets the lightning_amount_in_satoshi of this StoreBaseData.

        If true, lightning payment methods show amount in satoshi in the checkout page.  # noqa: E501

        :param lightning_amount_in_satoshi: The lightning_amount_in_satoshi of this StoreBaseData.  # noqa: E501
        :type: bool
        """

        self._lightning_amount_in_satoshi = lightning_amount_in_satoshi

    @property
    def lightning_private_route_hints(self):
        """Gets the lightning_private_route_hints of this StoreBaseData.  # noqa: E501

        Should private route hints be included in the lightning payment of the checkout page.  # noqa: E501

        :return: The lightning_private_route_hints of this StoreBaseData.  # noqa: E501
        :rtype: bool
        """
        return self._lightning_private_route_hints

    @lightning_private_route_hints.setter
    def lightning_private_route_hints(self, lightning_private_route_hints):
        """Sets the lightning_private_route_hints of this StoreBaseData.

        Should private route hints be included in the lightning payment of the checkout page.  # noqa: E501

        :param lightning_private_route_hints: The lightning_private_route_hints of this StoreBaseData.  # noqa: E501
        :type: bool
        """

        self._lightning_private_route_hints = lightning_private_route_hints

    @property
    def on_chain_with_ln_invoice_fallback(self):
        """Gets the on_chain_with_ln_invoice_fallback of this StoreBaseData.  # noqa: E501

        Include lightning invoice fallback to on-chain BIP21 payment url.  # noqa: E501

        :return: The on_chain_with_ln_invoice_fallback of this StoreBaseData.  # noqa: E501
        :rtype: bool
        """
        return self._on_chain_with_ln_invoice_fallback

    @on_chain_with_ln_invoice_fallback.setter
    def on_chain_with_ln_invoice_fallback(self, on_chain_with_ln_invoice_fallback):
        """Sets the on_chain_with_ln_invoice_fallback of this StoreBaseData.

        Include lightning invoice fallback to on-chain BIP21 payment url.  # noqa: E501

        :param on_chain_with_ln_invoice_fallback: The on_chain_with_ln_invoice_fallback of this StoreBaseData.  # noqa: E501
        :type: bool
        """

        self._on_chain_with_ln_invoice_fallback = on_chain_with_ln_invoice_fallback

    @property
    def redirect_automatically(self):
        """Gets the redirect_automatically of this StoreBaseData.  # noqa: E501

        After successfull payment, should the checkout page redirect the user automatically to the redirect URL of the invoice?  # noqa: E501

        :return: The redirect_automatically of this StoreBaseData.  # noqa: E501
        :rtype: bool
        """
        return self._redirect_automatically

    @redirect_automatically.setter
    def redirect_automatically(self, redirect_automatically):
        """Sets the redirect_automatically of this StoreBaseData.

        After successfull payment, should the checkout page redirect the user automatically to the redirect URL of the invoice?  # noqa: E501

        :param redirect_automatically: The redirect_automatically of this StoreBaseData.  # noqa: E501
        :type: bool
        """

        self._redirect_automatically = redirect_automatically

    @property
    def show_recommended_fee(self):
        """Gets the show_recommended_fee of this StoreBaseData.  # noqa: E501


        :return: The show_recommended_fee of this StoreBaseData.  # noqa: E501
        :rtype: bool
        """
        return self._show_recommended_fee

    @show_recommended_fee.setter
    def show_recommended_fee(self, show_recommended_fee):
        """Sets the show_recommended_fee of this StoreBaseData.


        :param show_recommended_fee: The show_recommended_fee of this StoreBaseData.  # noqa: E501
        :type: bool
        """

        self._show_recommended_fee = show_recommended_fee

    @property
    def recommended_fee_block_target(self):
        """Gets the recommended_fee_block_target of this StoreBaseData.  # noqa: E501

        The fee rate recommendation in the checkout page for the on-chain payment to be confirmed after 'x' blocks.  # noqa: E501

        :return: The recommended_fee_block_target of this StoreBaseData.  # noqa: E501
        :rtype: int
        """
        return self._recommended_fee_block_target

    @recommended_fee_block_target.setter
    def recommended_fee_block_target(self, recommended_fee_block_target):
        """Sets the recommended_fee_block_target of this StoreBaseData.

        The fee rate recommendation in the checkout page for the on-chain payment to be confirmed after 'x' blocks.  # noqa: E501

        :param recommended_fee_block_target: The recommended_fee_block_target of this StoreBaseData.  # noqa: E501
        :type: int
        """

        self._recommended_fee_block_target = recommended_fee_block_target

    @property
    def default_lang(self):
        """Gets the default_lang of this StoreBaseData.  # noqa: E501

        The default language to use in the checkout page. (The different translations available are listed [here](https://github.com/btcpayserver/btcpayserver/tree/master/BTCPayServer/wwwroot/locales)  # noqa: E501

        :return: The default_lang of this StoreBaseData.  # noqa: E501
        :rtype: str
        """
        return self._default_lang

    @default_lang.setter
    def default_lang(self, default_lang):
        """Sets the default_lang of this StoreBaseData.

        The default language to use in the checkout page. (The different translations available are listed [here](https://github.com/btcpayserver/btcpayserver/tree/master/BTCPayServer/wwwroot/locales)  # noqa: E501

        :param default_lang: The default_lang of this StoreBaseData.  # noqa: E501
        :type: str
        """

        self._default_lang = default_lang

    @property
    def custom_logo(self):
        """Gets the custom_logo of this StoreBaseData.  # noqa: E501

        URL to a logo to include in the checkout page.  # noqa: E501

        :return: The custom_logo of this StoreBaseData.  # noqa: E501
        :rtype: str
        """
        return self._custom_logo

    @custom_logo.setter
    def custom_logo(self, custom_logo):
        """Sets the custom_logo of this StoreBaseData.

        URL to a logo to include in the checkout page.  # noqa: E501

        :param custom_logo: The custom_logo of this StoreBaseData.  # noqa: E501
        :type: str
        """

        self._custom_logo = custom_logo

    @property
    def custom_css(self):
        """Gets the custom_css of this StoreBaseData.  # noqa: E501

        URL to a CSS stylesheet to include in the checkout page  # noqa: E501

        :return: The custom_css of this StoreBaseData.  # noqa: E501
        :rtype: str
        """
        return self._custom_css

    @custom_css.setter
    def custom_css(self, custom_css):
        """Sets the custom_css of this StoreBaseData.

        URL to a CSS stylesheet to include in the checkout page  # noqa: E501

        :param custom_css: The custom_css of this StoreBaseData.  # noqa: E501
        :type: str
        """

        self._custom_css = custom_css

    @property
    def html_title(self):
        """Gets the html_title of this StoreBaseData.  # noqa: E501

        The HTML title of the checkout page (when you over the tab in your browser)  # noqa: E501

        :return: The html_title of this StoreBaseData.  # noqa: E501
        :rtype: str
        """
        return self._html_title

    @html_title.setter
    def html_title(self, html_title):
        """Sets the html_title of this StoreBaseData.

        The HTML title of the checkout page (when you over the tab in your browser)  # noqa: E501

        :param html_title: The html_title of this StoreBaseData.  # noqa: E501
        :type: str
        """

        self._html_title = html_title

    @property
    def network_fee_mode(self):
        """Gets the network_fee_mode of this StoreBaseData.  # noqa: E501


        :return: The network_fee_mode of this StoreBaseData.  # noqa: E501
        :rtype: NetworkFeeMode
        """
        return self._network_fee_mode

    @network_fee_mode.setter
    def network_fee_mode(self, network_fee_mode):
        """Sets the network_fee_mode of this StoreBaseData.


        :param network_fee_mode: The network_fee_mode of this StoreBaseData.  # noqa: E501
        :type: NetworkFeeMode
        """

        self._network_fee_mode = network_fee_mode

    @property
    def pay_join_enabled(self):
        """Gets the pay_join_enabled of this StoreBaseData.  # noqa: E501

        If true, payjoin will be proposed in the checkout page if possible. ([More information](https://docs.btcpayserver.org/Payjoin/))  # noqa: E501

        :return: The pay_join_enabled of this StoreBaseData.  # noqa: E501
        :rtype: bool
        """
        return self._pay_join_enabled

    @pay_join_enabled.setter
    def pay_join_enabled(self, pay_join_enabled):
        """Sets the pay_join_enabled of this StoreBaseData.

        If true, payjoin will be proposed in the checkout page if possible. ([More information](https://docs.btcpayserver.org/Payjoin/))  # noqa: E501

        :param pay_join_enabled: The pay_join_enabled of this StoreBaseData.  # noqa: E501
        :type: bool
        """

        self._pay_join_enabled = pay_join_enabled

    @property
    def lazy_payment_methods(self):
        """Gets the lazy_payment_methods of this StoreBaseData.  # noqa: E501

        If true, payment methods are enabled individually upon user interaction in the invoice  # noqa: E501

        :return: The lazy_payment_methods of this StoreBaseData.  # noqa: E501
        :rtype: bool
        """
        return self._lazy_payment_methods

    @lazy_payment_methods.setter
    def lazy_payment_methods(self, lazy_payment_methods):
        """Sets the lazy_payment_methods of this StoreBaseData.

        If true, payment methods are enabled individually upon user interaction in the invoice  # noqa: E501

        :param lazy_payment_methods: The lazy_payment_methods of this StoreBaseData.  # noqa: E501
        :type: bool
        """

        self._lazy_payment_methods = lazy_payment_methods

    @property
    def default_payment_method(self):
        """Gets the default_payment_method of this StoreBaseData.  # noqa: E501

        The default payment method to load when displaying an invoice. It can be in the format of `BTC_LightningNetwork` to specify Lightning to be the default or `BTC_OnChain`/ `BTC` for on-chain to be the default.   # noqa: E501

        :return: The default_payment_method of this StoreBaseData.  # noqa: E501
        :rtype: str
        """
        return self._default_payment_method

    @default_payment_method.setter
    def default_payment_method(self, default_payment_method):
        """Sets the default_payment_method of this StoreBaseData.

        The default payment method to load when displaying an invoice. It can be in the format of `BTC_LightningNetwork` to specify Lightning to be the default or `BTC_OnChain`/ `BTC` for on-chain to be the default.   # noqa: E501

        :param default_payment_method: The default_payment_method of this StoreBaseData.  # noqa: E501
        :type: str
        """

        self._default_payment_method = default_payment_method

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(StoreBaseData, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, StoreBaseData):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    BTCPay Greenfield API

    A full API to use your BTCPay Server  # noqa: E501

    OpenAPI spec version: v1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class OnChainWalletUTXOData(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'comment': 'str',
        'amount': 'str',
        'link': 'str',
        'outpoint': 'str',
        'timestamp': 'AllOfOnChainWalletUTXODataTimestamp',
        'key_path': 'str',
        'address': 'str',
        'confirmations': 'float',
        'labels': 'list[LabelData]'
    }

    attribute_map = {
        'comment': 'comment',
        'amount': 'amount',
        'link': 'link',
        'outpoint': 'outpoint',
        'timestamp': 'timestamp',
        'key_path': 'keyPath',
        'address': 'address',
        'confirmations': 'confirmations',
        'labels': 'labels'
    }

    def __init__(self, comment=None, amount=None, link=None, outpoint=None, timestamp=None, key_path=None, address=None, confirmations=None, labels=None):  # noqa: E501
        """OnChainWalletUTXOData - a model defined in Swagger"""  # noqa: E501
        self._comment = None
        self._amount = None
        self._link = None
        self._outpoint = None
        self._timestamp = None
        self._key_path = None
        self._address = None
        self._confirmations = None
        self._labels = None
        self.discriminator = None
        if comment is not None:
            self.comment = comment
        if amount is not None:
            self.amount = amount
        if link is not None:
            self.link = link
        if outpoint is not None:
            self.outpoint = outpoint
        if timestamp is not None:
            self.timestamp = timestamp
        if key_path is not None:
            self.key_path = key_path
        if address is not None:
            self.address = address
        if confirmations is not None:
            self.confirmations = confirmations
        if labels is not None:
            self.labels = labels

    @property
    def comment(self):
        """Gets the comment of this OnChainWalletUTXOData.  # noqa: E501

        A comment linked to this utxo  # noqa: E501

        :return: The comment of this OnChainWalletUTXOData.  # noqa: E501
        :rtype: str
        """
        return self._comment

    @comment.setter
    def comment(self, comment):
        """Sets the comment of this OnChainWalletUTXOData.

        A comment linked to this utxo  # noqa: E501

        :param comment: The comment of this OnChainWalletUTXOData.  # noqa: E501
        :type: str
        """

        self._comment = comment

    @property
    def amount(self):
        """Gets the amount of this OnChainWalletUTXOData.  # noqa: E501

        the value of this utxo  # noqa: E501

        :return: The amount of this OnChainWalletUTXOData.  # noqa: E501
        :rtype: str
        """
        return self._amount

    @amount.setter
    def amount(self, amount):
        """Sets the amount of this OnChainWalletUTXOData.

        the value of this utxo  # noqa: E501

        :param amount: The amount of this OnChainWalletUTXOData.  # noqa: E501
        :type: str
        """

        self._amount = amount

    @property
    def link(self):
        """Gets the link of this OnChainWalletUTXOData.  # noqa: E501

        a link to the configured blockchain explorer to view the utxo  # noqa: E501

        :return: The link of this OnChainWalletUTXOData.  # noqa: E501
        :rtype: str
        """
        return self._link

    @link.setter
    def link(self, link):
        """Sets the link of this OnChainWalletUTXOData.

        a link to the configured blockchain explorer to view the utxo  # noqa: E501

        :param link: The link of this OnChainWalletUTXOData.  # noqa: E501
        :type: str
        """

        self._link = link

    @property
    def outpoint(self):
        """Gets the outpoint of this OnChainWalletUTXOData.  # noqa: E501

        outpoint of this utxo  # noqa: E501

        :return: The outpoint of this OnChainWalletUTXOData.  # noqa: E501
        :rtype: str
        """
        return self._outpoint

    @outpoint.setter
    def outpoint(self, outpoint):
        """Sets the outpoint of this OnChainWalletUTXOData.

        outpoint of this utxo  # noqa: E501

        :param outpoint: The outpoint of this OnChainWalletUTXOData.  # noqa: E501
        :type: str
        """

        self._outpoint = outpoint

    @property
    def timestamp(self):
        """Gets the timestamp of this OnChainWalletUTXOData.  # noqa: E501

        The time of the utxo  # noqa: E501

        :return: The timestamp of this OnChainWalletUTXOData.  # noqa: E501
        :rtype: AllOfOnChainWalletUTXODataTimestamp
        """
        return self._timestamp

    @timestamp.setter
    def timestamp(self, timestamp):
        """Sets the timestamp of this OnChainWalletUTXOData.

        The time of the utxo  # noqa: E501

        :param timestamp: The timestamp of this OnChainWalletUTXOData.  # noqa: E501
        :type: AllOfOnChainWalletUTXODataTimestamp
        """

        self._timestamp = timestamp

    @property
    def key_path(self):
        """Gets the key_path of this OnChainWalletUTXOData.  # noqa: E501

        the derivation path in relation to the HD account  # noqa: E501

        :return: The key_path of this OnChainWalletUTXOData.  # noqa: E501
        :rtype: str
        """
        return self._key_path

    @key_path.setter
    def key_path(self, key_path):
        """Sets the key_path of this OnChainWalletUTXOData.

        the derivation path in relation to the HD account  # noqa: E501

        :param key_path: The key_path of this OnChainWalletUTXOData.  # noqa: E501
        :type: str
        """

        self._key_path = key_path

    @property
    def address(self):
        """Gets the address of this OnChainWalletUTXOData.  # noqa: E501

        The wallet address of this utxo  # noqa: E501

        :return: The address of this OnChainWalletUTXOData.  # noqa: E501
        :rtype: str
        """
        return self._address

    @address.setter
    def address(self, address):
        """Sets the address of this OnChainWalletUTXOData.

        The wallet address of this utxo  # noqa: E501

        :param address: The address of this OnChainWalletUTXOData.  # noqa: E501
        :type: str
        """

        self._address = address

    @property
    def confirmations(self):
        """Gets the confirmations of this OnChainWalletUTXOData.  # noqa: E501

        The number of confirmations of this utxo  # noqa: E501

        :return: The confirmations of this OnChainWalletUTXOData.  # noqa: E501
        :rtype: float
        """
        return self._confirmations

    @confirmations.setter
    def confirmations(self, confirmations):
        """Sets the confirmations of this OnChainWalletUTXOData.

        The number of confirmations of this utxo  # noqa: E501

        :param confirmations: The confirmations of this OnChainWalletUTXOData.  # noqa: E501
        :type: float
        """

        self._confirmations = confirmations

    @property
    def labels(self):
        """Gets the labels of this OnChainWalletUTXOData.  # noqa: E501

        Labels linked to this transaction  # noqa: E501

        :return: The labels of this OnChainWalletUTXOData.  # noqa: E501
        :rtype: list[LabelData]
        """
        return self._labels

    @labels.setter
    def labels(self, labels):
        """Sets the labels of this OnChainWalletUTXOData.

        Labels linked to this transaction  # noqa: E501

        :param labels: The labels of this OnChainWalletUTXOData.  # noqa: E501
        :type: list[LabelData]
        """

        self._labels = labels

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(OnChainWalletUTXOData, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, OnChainWalletUTXOData):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
